==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ia.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Error Incognite",
    "The uploaded file was only partially uploaded" : "Le file incargate solmente esseva incargate partialmente",
    "No file was uploaded" : "Nulle file esseva incargate.",
    "Missing a temporary folder" : "Manca un dossier temporari",
    "Files" : "Files",
    "Home" : "Domo",
    "Close" : "Clauder",
    "Download" : "Discargar",
    "Delete" : "Deler",
    "Error" : "Error",
    "Name" : "Nomine",
    "Size" : "Dimension",
    "Modified" : "Modificate",
    "New" : "Nove",
    "File name cannot be empty." : "Le nomine de file non pote esser vacue.",
    "Upload" : "Incargar",
    "Text file" : "File de texto",
    "Folder" : "Dossier",
    "New folder" : "Nove dossier",
    "A new file or folder has been <strong>created</strong>" : "Un nove file o dossier ha essite <strong>create</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un nove file o dossier ha essite <strong>modificate</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un nove file o dossier ha essite <strong>delite</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un file o un dossier ha essite <strong>restabilite</strong>",
    "You created %1$s" : "Tu creava %1$s",
    "%2$s created %1$s" : "%2$s creava %1$s",
    "%1$s was created in a public folder" : "%1$s esseva create in un dossier public",
    "You changed %1$s" : "Tu modificava %1$s",
    "%2$s changed %1$s" : "%2$s modificava %1$s",
    "You deleted %1$s" : "Tu  deleva %1$s",
    "%2$s deleted %1$s" : "%2$s deleva %1$s",
    "You restored %1$s" : "Tu restabiliva %1$s",
    "%2$s restored %1$s" : "%2$s restabilite %1$s",
    "Upload (max. %s)" : "Incargar (max. %s)",
    "Maximum upload size" : "Dimension maxime de incargamento",
    "Save" : "Salveguardar",
    "Settings" : "Configurationes",
    "Upload too large" : "Incargamento troppo longe"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ia.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Error Incognite",
    "The uploaded file was only partially uploaded" : "Le file incargate solmente esseva incargate partialmente",
    "No file was uploaded" : "Nulle file esseva incargate.",
    "Missing a temporary folder" : "Manca un dossier temporari",
    "Files" : "Files",
    "Home" : "Domo",
    "Close" : "Clauder",
    "Download" : "Discargar",
    "Delete" : "Deler",
    "Unshare" : "Leva compartir",
    "Name" : "Nomine",
    "Size" : "Dimension",
    "Modified" : "Modificate",
    "New" : "Nove",
    "File name cannot be empty." : "Le nomine de file non pote esser vacue.",
    "Folder" : "Dossier",
    "New folder" : "Nove dossier",
    "Upload" : "Incargar",
    "A new file or folder has been <strong>created</strong>" : "Un nove file o dossier ha essite <strong>create</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un nove file o dossier ha essite <strong>modificate</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un nove file o dossier ha essite <strong>delite</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un file o un dossier ha essite <strong>restabilite</strong>",
    "You created %1$s" : "Tu creava %1$s",
    "%2$s created %1$s" : "%2$s creava %1$s",
    "%1$s was created in a public folder" : "%1$s esseva create in un dossier public",
    "You changed %1$s" : "Tu modificava %1$s",
    "%2$s changed %1$s" : "%2$s modificava %1$s",
    "You deleted %1$s" : "Tu  deleva %1$s",
    "%2$s deleted %1$s" : "%2$s deleva %1$s",
    "You restored %1$s" : "Tu restabiliva %1$s",
    "%2$s restored %1$s" : "%2$s restabilite %1$s",
    "Upload (max. %s)" : "Incargar (max. %s)",
    "Maximum upload size" : "Dimension maxime de incargamento",
    "Save" : "Salveguardar",
    "Settings" : "Configurationes",
    "Upload too large" : "Incargamento troppo longe",
    "Text file" : "File de texto"
},
"nplurals=2; plural=(n != 1);");
